@@ -1,8 +1,8 @@
-from stactools.goes.dataset import Dataset
 import click
 import os.path
 
 from stactools.goes import stac
+from stactools.goes import cog
 
 
 def create_goes_command(cli):
@@ -14,23 +14,24 @@ def create_goes_command(cli):
                   short_help="Creates a STAC item from a GOES netcdf file")
     @click.argument("href")
     @click.argument("destination")
-    @click.option("-c",
-                  "--cogify",
-                  is_flag=True,
-                  help="Convert the netcdf to two COGs")
-    @click.option("--tight-geometry/--no-tight-geometry", default=False)
-    def create_item(href, destination, cogify, tight_geometry):
+    @click.option(
+        "-c",
+        "--cogify",
+        is_flag=True,
+        help="Convert the netcdf into COGs. COG Asset HREFs will be local paths"
+    )
+    def create_item(href, destination, cogify):
         """Creates a STAC item from a GOES netcdf file.
 
         If `--cogify` is provided, will produce two COGs, one for the data and
         one for the data quality field.
         """
-        dataset = Dataset(href, tight_geometry)
         if cogify:
-            cogs = dataset.cogify(destination)
+            cogs = cog.cogify(href, destination)
         else:
             cogs = {}
-        item = stac.create_item_from_dataset(dataset, cogs=cogs)
+        item = stac.create_item(
+            [stac.ProductHrefs(nc_href=href, cog_hrefs=cogs)])
         path = os.path.join(destination, f"{item.id}.json")
         item.set_self_href(path)
         item.validate()
